@@ -2,6 +2,7 @@
 varying <- function(x, ...) UseMethod("varying") # , x
 
 varying.default <- function(x, g = NULL, any_group = TRUE, use.g.names = TRUE, ...) {
+  if(is.matrix(x) && !inherits(x, "matrix")) return(varying.matrix(x, g, any_group, use.g.names, ...))
   if(!missing(...)) unused_arg_action(match.call(), ...)
   if(is.null(g)) return(.Call(Cpp_varying,x,0L,0L,any_group))
   if(is.atomic(g)) {
@@ -57,11 +58,11 @@ varying.data.frame <- function(x, by = NULL, cols = NULL, any_group = TRUE, use.
       gn <- ckmatch(all.vars(by[[3L]]), nam)
     } else {
       gn <- ckmatch(all.vars(by), nam)
-      cols <- if(is.null(cols)) seq_along(unclass(x))[-gn] else cols2int(cols, x, nam)
+      cols <- if(is.null(cols)) seq_along(unclass(x))[-gn] else cols2int(cols, x, nam, FALSE)
     }
     by <- if(length(gn) == 1L) .subset2(x, gn) else GRP.default(x, gn, return.groups = use.g.names && !any_group, call = FALSE)
     x <- fcolsubset(x, cols)
-  } else if(!is.null(cols)) x <- colsubset(x, cols)
+  } else if(length(cols)) x <- colsubset(x, cols)
 
   if(is.null(by)) return(.Call(Cpp_varyingl,x,0L,0L,any_group,drop))
   if(is.atomic(by)) {
@@ -75,7 +76,7 @@ varying.data.frame <- function(x, by = NULL, cols = NULL, any_group = TRUE, use.
     return(.Call(Cpp_varyingl,x,attr(by,"N.groups"),by,any_group,drop))
   }
   if(!is.GRP(by)) by <- GRP.default(by, return.groups = use.g.names && !any_group, call = FALSE)
-  if(use.g.names && !any_group && !inherits(x, "data.table") && !is.null(groups <- GRPnames(by)))
+  if(use.g.names && !any_group && !inherits(x, "data.table") && length(groups <- GRPnames(by)))
     return(setRnDF(.Call(Cpp_varyingl,x,by[[1L]],by[[2L]],any_group,FALSE), groups))
   .Call(Cpp_varyingl,x,by[[1L]],by[[2L]],any_group,drop)
 }
@@ -106,7 +107,7 @@ varying.grouped_df <- function(x, any_group = TRUE, use.g.names = FALSE, drop =
   }
   ax <- attributes(x)
   ax[["groups"]] <- NULL
-  ax[["class"]] <- ax[["class"]][ax[["class"]] != "grouped_df"]
+  ax[["class"]] <- fsetdiff(ax[["class"]], c("GRP_df", "grouped_df"))
   ax[["row.names"]] <- if(use.g.names) GRPnames(g) else .set_row_names(g[[1L]])
   if(!all(ngn)) {
     if(keep.group_vars) {
@@ -209,7 +210,7 @@ varying.grouped_df <- function(x, any_group = TRUE, use.g.names = FALSE, drop =
 #       }
 #     } else {
 #       if(!is.GRP(g)) g <- GRP.default(g, return.groups = use.g.names && !any_group, call = FALSE)
-#       if(use.g.names && !any_group && !inherits(x, "data.table") && !is.null(groups <- GRPnames(g)))
+#       if(use.g.names && !any_group && !inherits(x, "data.table") && length(groups <- GRPnames(g)))
 #         return(setRnDF(.Call(Cpp_varyingl,x,g[[1L]],g[[2L]],any_group,FALSE), groups)) else
 #           return(.Call(Cpp_varyingl,x,g[[1L]],g[[2L]],any_group,drop))
 #     }
@@ -242,7 +243,7 @@ varying.grouped_df <- function(x, any_group = TRUE, use.g.names = FALSE, drop =
 #     attributes(x) <- NULL
 #     if(nTRAl) {
 #       ax[["groups"]] <- NULL
-#       ax[["class"]] <- ax[["class"]][ax[["class"]] != "grouped_df"]
+#       ax[["class"]] <- fsetdiff(ax[["class"]], c("GRP_df", "grouped_df"))
 #       ax[["row.names"]] <- if(use.g.names && !any_group) GRPnames(g) else if(!any_group) .set_row_names(g[[1L]]) else 1L
 #       if(gl) {
 #         if(keep.group_vars) {
