@@ -1,6 +1,6 @@
 context("fmedian and fnth")
 
-rm(list = ls())
+# rm(list = ls())
 
 x <- rnorm(100)
 w <- as.integer(round(10*abs(rnorm(100))))  # -> Numeric precision issues in R
